| reviews_test | R Documentation |
A test sample data used for testing analysis functions. It differs from reviews data.
The text column in this data frame is similar to the comment column in the reviews
data frame. Note that this data frame contains 170 texts that are in common, verbatim,
with comments in the reviews dataset. This is because some users made the same comments.
The id column shows that these are not the same observations, just similarly worded
comments from different reviews.
reviews_test
A tbl_df with with 1,481 rows and 4 variables:
Rating score, out of 5.
Comment text, in Turkish.
n for negative, p for positive.
Rating ID.
reviews_test
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.