A test sample data used for testing analysis functions. It differs from reviews data.
The text column in this data frame is similar to the comment column in the reviews
data frame. Note that this data frame contains 170 texts that are in common, verbatim,
with comments in the reviews dataset. This is because some users made the same comments.
The id column shows that these are not the same observations, just similarly worded
comments from different reviews.